<?php

namespace Drupal\last_tweets\Service;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Language\LanguageManager;
use Drupal\last_tweets\Gateway\LastTweetsGateway;

/**
 * Class LastTweetsManager
 *
 * @package Drupal\last_tweets\Service
 */
class LastTweetsManager {

  const DEFAULTTWEETLIMIT = 3;

  /**
   * @var \Drupal\last_tweets\Gateway\LastTweetsGateway
   */
  protected $lastTweetsGateway;

  /**
   * @var \Drupal\last_tweets\Service\NormalizeTweetsManager
   */
  protected $normalizeTweetsManager;

  /**
   * @var \Drupal\Core\Config\Config|\Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * @var array
   */
  protected $settings;

  /**
   * @var \Drupal\Core\Language\LanguageManager
   */
  protected $languageManager;

  /**
   * @var string
   */
  protected $languageId;

  /**
   * @var string
   */
  protected $defaultLanguageId;

  /**
   * @var array|mixed|null
   */
  protected $useDefaultConfigForAllLanguages;

  /**
   * @var array|mixed|null
   */
  protected $userName;

  /**
   * @var array|mixed|null
   */
  protected $consumerKey;

  /**
   * @var array|mixed|null
   */
  protected $secretKey;

  /**
   * @var array|mixed|null
   */
  protected $accessToken;

  /**
   * @var array|mixed|null
   */
  protected $accessTokenSecret;

  /**
   * LastTweetsService constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactory $config
   * @param \Drupal\Core\Language\LanguageManager $languageManager
   * @param \Drupal\last_tweets\Gateway\LastTweetsGateway $lastTweetsGateway
   * @param \Drupal\last_tweets\Service\NormalizeTweetsManager $normalizeTweetsManager
   */
  public function __construct(
    ConfigFactory $config,
    LanguageManager $languageManager,
    LastTweetsGateway $lastTweetsGateway,
    NormalizeTweetsManager $normalizeTweetsManager
  ) {
    $this->config = $config->getEditable('last_tweets.settings');
    $this->languageManager = $languageManager;
    $this->lastTweetsGateway = $lastTweetsGateway;
    $this->normalizeTweetsManager = $normalizeTweetsManager;

    $this->settings['language_id'] = ($this->config->get('use_for_all_' . $this->defaultLanguageId)) ? $this->languageManager->getDefaultLanguage()
      ->getId() : $this->languageManager->getCurrentLanguage()->getId();
    $this->settings['twitter_username'] = $this->config->get('twitter_username_' . $this->settings['language_id']);
    $this->settings['consumer_key'] = $this->config->get('consumer_key_' . $this->settings['language_id']);
    $this->settings['secret_key'] = $this->config->get('secret_key_' . $this->settings['language_id']);
    $this->settings['access_token'] = $this->config->get('access_token_' . $this->settings['language_id']);
    $this->settings['access_token_secret'] = $this->config->get('access_token_secret_' . $this->settings['language_id']);
  }

  /**
   * @param int $limit
   *
   * @return array
   */
  public function getTweets($limit = self::DEFAULTTWEETLIMIT) {
    $tweets = $this->lastTweetsGateway->getLastTweets($limit, $this->settings);
    return $tweets ? $this->normalizeTweetsManager->normalize($tweets) : NULL;
  }

}